==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/enummessagesplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/enummessagesplugin/em.png
  0x0,0x0,0x1,0x52,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x1,0x19,0x49,0x44,0x41,0x54,0x78,0x5e,0xa5,0x50,0x3d,0x4e,0x86,0x50,
  0x10,0x5c,0x7e,0x5a,0xb,0xee,0x60,0xe5,0x1,0x28,0xa0,0x24,0x86,0x83,0x8,0xd,
  0xcd,0xd7,0x12,0xfe,0x13,0x21,0x10,0x7a,0xad,0x8,0x67,0xa0,0x37,0x11,0x1a,0xee,
  0xc0,0x21,0x68,0xa9,0xf5,0x2d,0xc5,0x86,0x15,0x7c,0x6a,0x9c,0x64,0xf2,0xfe,0x76,
  0x67,0xe7,0x8d,0x2,0x0,0xf,0x82,0x4f,0x82,0xbe,0xe0,0x1d,0xfc,0x1e,0x58,0xff,
  0x8e,0x2,0xc1,0x38,0x8e,0x2f,0xa6,0x69,0x2,0x42,0x51,0x14,0x20,0xd0,0xf9,0xbc,
  0x4e,0xd3,0x4,0xae,0xeb,0x6,0x78,0xfa,0xd8,0xb6,0xd,0xd6,0x75,0xc5,0x47,0x46,
  0x55,0x55,0xa5,0x77,0x86,0x61,0x80,0x7e,0x9c,0x84,0x6c,0xdb,0x16,0xc2,0x30,0xdc,
  0xb,0x9b,0xa6,0x39,0x4e,0xa6,0x7d,0x9a,0xa6,0xb4,0xd7,0xbf,0x34,0xb3,0x29,0x51,
  0x14,0x49,0xdd,0x8,0x30,0x7,0x38,0x99,0x44,0x90,0x75,0x5d,0x1f,0x8b,0x69,0xcd,
  0xb2,0xc,0x5,0x4f,0x2,0x78,0xc9,0xec,0xc6,0x71,0x2c,0xcb,0x81,0xb,0x70,0xdb,
  0xe4,0x80,0x4,0xc5,0xbf,0x59,0xf3,0x65,0x6,0xcb,0xb2,0xc0,0x30,0xc,0xe0,0x38,
  0xe,0x58,0x96,0x5,0x49,0x92,0x9c,0x26,0x4b,0x33,0xc0,0x66,0xcf,0xf3,0xa0,0xef,
  0x7b,0xb0,0x6d,0x1b,0xaa,0xaa,0xc2,0xa7,0x53,0xe,0x45,0x51,0x5c,0x3a,0xa0,0x66,
  0xdf,0xf7,0xaf,0x6d,0x73,0x37,0x5c,0x40,0xd3,0x34,0x6c,0xde,0xf7,0x5d,0xd7,0xed,
  0x49,0x97,0x65,0x89,0xcf,0x34,0xf1,0xbb,0xc,0x8e,0x41,0xb1,0xc2,0x3c,0xcf,0x7f,
  0xcc,0x0,0x7d,0x3c,0xcf,0xf3,0x7c,0x55,0x28,0xbd,0xc3,0x1e,0x81,0x1b,0xca,0xdc,
  0xb,0x3e,0xa,0xbe,0xc2,0xdf,0x10,0x8,0xbe,0xc1,0x7f,0xf1,0x9,0x70,0x4e,0x50,
  0x23,0x19,0x4a,0x8d,0x45,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // em.png
  0x0,0x6,
  0x6,0xc0,0x57,0x47,
  0x0,0x65,
  0x0,0x6d,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/em.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/enummessagesplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/enummessagesplugin/em.png
  0x0,0x0,0x1,0x52,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x1,0x19,0x49,0x44,0x41,0x54,0x78,0x5e,0xa5,0x50,0x3d,0x4e,0x86,0x50,
  0x10,0x5c,0x7e,0x5a,0xb,0xee,0x60,0xe5,0x1,0x28,0xa0,0x24,0x86,0x83,0x8,0xd,
  0xcd,0xd7,0x12,0xfe,0x13,0x21,0x10,0x7a,0xad,0x8,0x67,0xa0,0x37,0x11,0x1a,0xee,
  0xc0,0x21,0x68,0xa9,0xf5,0x2d,0xc5,0x86,0x15,0x7c,0x6a,0x9c,0x64,0xf2,0xfe,0x76,
  0x67,0xe7,0x8d,0x2,0x0,0xf,0x82,0x4f,0x82,0xbe,0xe0,0x1d,0xfc,0x1e,0x58,0xff,
  0x8e,0x2,0xc1,0x38,0x8e,0x2f,0xa6,0x69,0x2,0x42,0x51,0x14,0x20,0xd0,0xf9,0xbc,
  0x4e,0xd3,0x4,0xae,0xeb,0x6,0x78,0xfa,0xd8,0xb6,0xd,0xd6,0x75,0xc5,0x47,0x46,
  0x55,0x55,0xa5,0x77,0x86,0x61,0x80,0x7e,0x9c,0x84,0x6c,0xdb,0x16,0xc2,0x30,0xdc,
  0xb,0x9b,0xa6,0x39,0x4e,0xa6,0x7d,0x9a,0xa6,0xb4,0xd7,0xbf,0x34,0xb3,0x29,0x51,
  0x14,0x49,0xdd,0x8,0x30,0x7,0x38,0x99,0x44,0x90,0x75,0x5d,0x1f,0x8b,0x69,0xcd,
  0xb2,0xc,0x5,0x4f,0x2,0x78,0xc9,0xec,0xc6,0x71,0x2c,0xcb,0x81,0xb,0x70,0xdb,
  0xe4,0x80,0x4,0xc5,0xbf,0x59,0xf3,0x65,0x6,0xcb,0xb2,0xc0,0x30,0xc,0xe0,0x38,
  0xe,0x58,0x96,0x5,0x49,0x92,0x9c,0x26,0x4b,0x33,0xc0,0x66,0xcf,0xf3,0xa0,0xef,
  0x7b,0xb0,0x6d,0x1b,0xaa,0xaa,0xc2,0xa7,0x53,0xe,0x45,0x51,0x5c,0x3a,0xa0,0x66,
  0xdf,0xf7,0xaf,0x6d,0x73,0x37,0x5c,0x40,0xd3,0x34,0x6c,0xde,0xf7,0x5d,0xd7,0xed,
  0x49,0x97,0x65,0x89,0xcf,0x34,0xf1,0xbb,0xc,0x8e,0x41,0xb1,0xc2,0x3c,0xcf,0x7f,
  0xcc,0x0,0x7d,0x3c,0xcf,0xf3,0x7c,0x55,0x28,0xbd,0xc3,0x1e,0x81,0x1b,0xca,0xdc,
  0xb,0x3e,0xa,0xbe,0xc2,0xdf,0x10,0x8,0xbe,0xc1,0x7f,0xf1,0x9,0x70,0x4e,0x50,
  0x23,0x19,0x4a,0x8d,0x45,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,
  0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // em.png
  0x0,0x6,
  0x6,0xc0,0x57,0x47,
  0x0,0x65,
  0x0,0x6d,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,
  // :/icons/em.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x23,0x5b,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
